# collapse-object [![NPM version](https://badge.fury.io/js/collapse-object.svg)](http://badge.fury.io/js/collapse-object)

> Collapse an object into a string using the syntax from expand-object. This syntax is pretty handy for setting command line arguments, for expanding/collapsing test fixtures, etc.

## Install

Install with [npm](https://www.npmjs.com/)

```sh
$ npm i collapse-object --save
```

## Usage

```js
var collapse = require('collapse-object');

collapse({a: {b: {c: [1, 2, 3]}}})
//=> 'a.b.c:1,2,3'
```

Re-expand a collapsed string with [expand-object](https://github.com/jonschlinkert/expand-object):

```js
var expand = require('expand-object');
//=> {a: {b: {c: [1, 2, 3]}}}
```

### collapse an object

```js
collapse({a: 'b'})
//=> 'a:b'

expand('a:b')
//=> {a: 'b'}
```

### collapse objects with number values

```js
collapse({a: 0})
//=> 'a:0'
collapse({a: 1})
//=> 'a:1'

expand('a:0')
//=> {a: 0}
expand('a:1')
//=> {a: 1}
```

### collapse objects with boolean values

```js
collapse({a: false})
//=> 'a:false'
collapse({a: true})
//=> 'a:true'

expand('a:false')
//=> {a: false}
expand('a:true')
//=> {a: true}
```

### collapse array with boolean values

```js
collapse({a: [1, 2, 3]})
//=> 'a:1,2,3'
collapse({a: {b: [1, 2, 3]}, c: 'd'})
//=> 'a.b:1,2,3|c:d'

expand('a:1,2,3')
//=> {a: [1, 2, 3]}
expand('a.b:1,2,3|c:d')
//=> {a: {b: [1, 2, 3]}, c: 'd'}
```

### collapse nested objects with boolean values

```js
collapse({a: {b: true}})
//=> 'a.b:true'
collapse({a: {b: [true]}})
//=> 'a.b:true,'
collapse({a: {b: [true, false]}})
//=> 'a.b:true,false'
collapse({a: {b: [true, false], c: {d: 'e'}}})
//=> 'a.b:true,false|a.c.d:e'

expand('a.b:true')
//=> {a: {b: true}}
expand('a.b:true')
//=> {a: {b: true}}
expand('a.b:true,')
//=> {a: {b: [true]}}
expand('a.b:true,false')
//=> {a: {b: [true, false]}}
expand('a.b:true,false|a.c.d:e')
//=> {a: {b: [true, false], c: {d: 'e'}}}
```

### collapse complex objects

```js
collapse({a: {b: 'c', d: 'e'}, f: 'g'})
//=> 'a.b:c|a.d:e|f:g'
collapse({a: 'b', c: 'd', e: {f: 'g', h: 'i', j: {k: {l: 'm'}}}})
//=> 'a:b|c:d|e.f:g|e.h:i|e.j.k.l:m'
collapse({a: 'b', c: 'd', e: {f: 'g', h: ['i', 'j', 'k']}})
//=> 'a:b|c:d|e.f:g|e.h:i,j,k'
collapse({a: 'b', c: 'd', e: {f: 'g', h: ['i', 'j', 'k', {one: 'two'}]}})
//=> 'a:b|c:d|e.f:g|e.h:i,j,k,one:two'

expand('a.b:c|a.d:e|f:g')
//=> {a: {b: 'c', d: 'e'}, f: 'g'}
expand('a:b|c:d|e.f:g|e.h:i|e.j.k.l:m')
//=> {a: 'b', c: 'd', e: {f: 'g', h: 'i', j: {k: {l: 'm'}}}}
expand('a:b|c:d|e.f:g|e.h:i,j,k')
//=> {a: 'b', c: 'd', e: {f: 'g', h: ['i', 'j', 'k']}}
expand('a:b|c:d|e.f:g|e.h:i,j,k,one:two')
//=> {a: 'b', c: 'd', e: {f: 'g', h: ['i', 'j', 'k', {one: 'two'}]}}
```

## Related projects

* [expand-object](https://github.com/jonschlinkert/expand-object): Expand a string into a JavaScript object using a simple notation. Use the CLI or… [more](https://github.com/jonschlinkert/expand-object)
* [kind-of](https://github.com/jonschlinkert/kind-of): Get the native type of a value.
* [regex-flags](https://github.com/jonschlinkert/regex-flags): Does one simple thing - gets the flags from a regular expression. Useful for cloning… [more](https://github.com/jonschlinkert/regex-flags)

## Running tests

Install dev dependencies:

```sh
$ npm i -d && npm test
```

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/collapse-object/issues/new)

## Author

**Jon Schlinkert**

+ [github/jonschlinkert](https://github.com/jonschlinkert)
+ [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License

Copyright © 2015 Jon Schlinkert
Released under the MIT license.

***

_This file was generated by [verb-cli](https://github.com/assemble/verb-cli) on August 05, 2015._