# to-flag [![NPM version](https://badge.fury.io/js/to-flag.svg)](http://badge.fury.io/js/to-flag)  [![Build Status](https://travis-ci.org/jonschlinkert/to-flag.svg)](https://travis-ci.org/jonschlinkert/to-flag)

> Create a command-line argument from a string or string (key) and value.

## Install

Install with [npm](https://www.npmjs.com/)

```sh
$ npm i to-flag --save
```

## Usage

```js
var toFlag = require('to-flag');

toFlag('abc');
//=> '--abc'

toFlag('abc', true);
//=> '--abc'

toFlag('abc', 'xyz');
//=> '--abc=xyz'

toFlag('abc', 'true');
//=> '--abc=true'

toFlag('abc', 10);
//=> '--abc=10'
```

**casing**

Keys that are camelcase or contain spaces will be dash-cased:

```js
toFlag('fooBar');
//=> '--foo-bar'

toFlag('a b c');
//=> '--a-b-c'

toFlag('A');
//=> '--a'
```

## Usage example

```js
var obj = {
  foo: 'bar',
  abc: true,
  xyz: 10,
  one: false
};

var args = Object.keys(obj).map(function (key) {
  return toFlag(key, obj[key]);
});
//=> ['--foo=bar', '--abc', '--xyz=10', '--no-one']
```

## Options

### invert

When the value is `false` an inverted flag is created by default:

```js
toFlag('a', false);
//=> '--no-a'
```

To disable inversion, pass `false` on the options:

```js
toFlag('a', false, {invert: false});
//=> '--a'
```

## Related

* [minimist-plugins](https://github.com/jonschlinkert/minimist-plugins): Simple wrapper to make minimist pluggable. ~20 sloc.
* [minimist-events](https://github.com/jonschlinkert/minimist-events): Add events to minimist, ~30 sloc.
* [minimist-methods](https://github.com/jonschlinkert/minimist-methods): Map your node.js application's methods to command line arguments.
* [minimist-expand](https://github.com/jonschlinkert/minimist-expand): Expand minimist args with expand-object.
* [to-flags](https://github.com/jonschlinkert/to-flags): Convert the properties of an object to command line flags.

## Run tests

Install dev dependencies:

```sh
$ npm i -d && npm test
```

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/to-flag/issues/new)

## Author

**Jon Schlinkert**

+ [github/jonschlinkert](https://github.com/jonschlinkert)
+ [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

This was originally inspired by [grunt.option](https://github.com/gruntjs/grunt/blob/master/lib/grunt/option.js#L40).

## License

Copyright © 2015 Jon Schlinkert
Released under the MIT license.

***

_This file was generated by [verb-cli](https://github.com/assemble/verb-cli) on August 07, 2015._